pub struct AdsSettings {Show 15 fields
pub chest_upgrade_speedup: AdSpeedupConfig,
pub talent_upgrade_speedup: AdSpeedupConfig,
pub free_ability_case_cooldown_sec: u64,
pub skill_gacha_ad_daily_limit: u64,
pub skill_gacha_ad_rolls: u64,
pub pet_gacha_ad_daily_limit: u64,
pub pet_gacha_ad_rolls: u64,
pub afk_boost_ad_daily_limit: u64,
pub afk_boost_multiplier: f64,
pub daily_booster_ad_daily_limit: u64,
pub daily_booster_ad_buff_template_id: BuffTemplateId,
pub daily_booster_ad_buff_duration: i64,
pub arena_refresh_ad_daily_limit: u64,
pub dungeon_raid_ad_daily_limit: u64,
pub bird_ad: BirdAdConfig,
}Fields
chest_upgrade_speedup: AdSpeedupConfigtalent_upgrade_speedup: AdSpeedupConfigfree_ability_case_cooldown_sec: u64skill_gacha_ad_daily_limit: u64skill_gacha_ad_rolls: u64pet_gacha_ad_daily_limit: u64pet_gacha_ad_rolls: u64afk_boost_ad_daily_limit: u64afk_boost_multiplier: f64daily_booster_ad_daily_limit: u64daily_booster_ad_buff_template_id: BuffTemplateIddaily_booster_ad_buff_duration: i64arena_refresh_ad_daily_limit: u64dungeon_raid_ad_daily_limit: u64bird_ad: BirdAdConfigTrait Implementations
Sourceimpl Clone for AdsSettings
impl Clone for AdsSettings
Sourcefn clone(&self) -> AdsSettings
fn clone(&self) -> AdsSettings
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AdsSettings
impl Debug for AdsSettings
Sourceimpl<'de> Deserialize<'de> for AdsSettings
impl<'de> Deserialize<'de> for AdsSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AdsSettings
impl JsonSchema for AdsSettings
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for AdsSettings
impl Serialize for AdsSettings
Sourceimpl Tsify for AdsSettings
impl Tsify for AdsSettings
const DECL: &'static str = "export interface AdsSettings {\n chest_upgrade_speedup: AdSpeedupConfig;\n talent_upgrade_speedup: AdSpeedupConfig;\n free_ability_case_cooldown_sec: number;\n skill_gacha_ad_daily_limit: number;\n skill_gacha_ad_rolls: number;\n pet_gacha_ad_daily_limit: number;\n pet_gacha_ad_rolls: number;\n afk_boost_ad_daily_limit: number;\n afk_boost_multiplier: number;\n daily_booster_ad_daily_limit: number;\n daily_booster_ad_buff_template_id: BuffTemplateId;\n daily_booster_ad_buff_duration: number;\n arena_refresh_ad_daily_limit: number;\n dungeon_raid_ad_daily_limit: number;\n bird_ad: BirdAdConfig;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>