pub struct BirdVariant {
pub id: BirdVariantId,
pub spine_path: String,
pub bundle_id: BundleId,
}Fields
id: BirdVariantIdspine_path: Stringbundle_id: BundleIdTrait Implementations
Sourceimpl Clone for BirdVariant
impl Clone for BirdVariant
Sourcefn clone(&self) -> BirdVariant
fn clone(&self) -> BirdVariant
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BirdVariant
impl Debug for BirdVariant
Sourceimpl<'de> Deserialize<'de> for BirdVariant
impl<'de> Deserialize<'de> for BirdVariant
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for BirdVariant
impl JsonSchema for BirdVariant
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for BirdVariant
impl Serialize for BirdVariant
Sourceimpl Tsify for BirdVariant
impl Tsify for BirdVariant
const DECL: &'static str = "export interface BirdVariant {\n id: BirdVariantId;\n spine_path: string;\n bundle_id: BundleId;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>